package com.yanzhu.jh.project.service;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectAttendanceGroup;

/**
 * 广联达班组信息Service接口
 * 
 * @author ruoyi
 * @date 2023-09-26
 */
public interface ISurProjectAttendanceGroupService 
{
    /**
     * 查询广联达班组信息
     * 
     * @param id 广联达班组信息主键
     * @return 广联达班组信息
     */
    public SurProjectAttendanceGroup selectSurProjectAttendanceGroupById(Long id);

    /**
     * 查询广联达班组信息列表
     * 
     * @param surProjectAttendanceGroup 广联达班组信息
     * @return 广联达班组信息集合
     */
    public List<SurProjectAttendanceGroup> selectSurProjectAttendanceGroupList(SurProjectAttendanceGroup surProjectAttendanceGroup);

    /**
     * 新增广联达班组信息
     * 
     * @param surProjectAttendanceGroup 广联达班组信息
     * @return 结果
     */
    public int insertSurProjectAttendanceGroup(SurProjectAttendanceGroup surProjectAttendanceGroup);

    /**
     * 修改广联达班组信息
     * 
     * @param surProjectAttendanceGroup 广联达班组信息
     * @return 结果
     */
    public int updateSurProjectAttendanceGroup(SurProjectAttendanceGroup surProjectAttendanceGroup);

    /**
     * 批量删除广联达班组信息
     * 
     * @param ids 需要删除的广联达班组信息主键集合
     * @return 结果
     */
    public int deleteSurProjectAttendanceGroupByIds(Long[] ids);

    /**
     * 删除广联达班组信息信息
     * 
     * @param id 广联达班组信息主键
     * @return 结果
     */
    public int deleteSurProjectAttendanceGroupById(Long id);

    public void add(SurProjectAttendanceGroup group);
}
